@@ -992,8 +992,11 @@ class FormatBtrfsCompressed(FormatBtrfs):
             if self.purpose == "root":
                 # disable btrfs compression for /boot directory in root partition
                 # and usr/share/grub for unicode.pf2
-                Btrfs(self.dev).set_compression("boot", "")
-                Btrfs(self.dev).set_compression("usr/share/grub", "")
+                for dn in ("boot", "usr/share/grub", "var/calculate/linux"):
+                    Btrfs(self.dev).set_compression(dn, "")
+            if self.purpose == "calculate":
+                Btrfs(self.dev).set_compression("linux", "")
+
         except BtrfsError as e:
             raise DistributiveError(
                 _("Failed to set btrfs compression for {}").format(self.dev))
@@ -1169,6 +1172,7 @@ class PartitionDistributive(Distributive):
         # if has separate /boot partition
         bootmp = ["/boot", "/"]
         purpose_map = {"/boot": "boot",
+                       "/var/calculate","calculate",
                        "/": "root"}
         # format all get partition
         for fileSystem, dev, newID, mp in formatPartitions:
