@@ -396,9 +396,15 @@ class VariableClAutopartitionDefaultFormat(Variable):
     """
     Формат файловой системы
     """
+    type = "choice"
+
     def get(self):
         return FileSystemManager.defaultFS['hdd']
 
+    def choice(self):
+        return [k for k,v in FileSystemManager.supportFS.items()
+                if "hdd" in v.get('type',[])]
+
 
 class VariableClAutopartitionCalculateSize(Variable):
     """
