@@ -2341,7 +2341,7 @@ class VariableOsInstallFstabMountConf(DeviceHelper, ReadonlyVariable):
         else:
             fs_orig = fs
         ret = "{dev}\t{mp}\t{fs}\t{opts}\t{spec}".format(
-            dev=used, mp=mp, fs=fs, opts=opts, spec=spec
+            dev=used, mp=mp, fs=fs_orig, opts=opts, spec=spec
         )
         if used.startswith("UUID"):
             return "# %s was on %s during installation\n%s" % (mp, dev, ret)
